==> okteta-0.25.3.tar.xz: okteta-0.25.3/libs/kasten/controllers/document/versionview/versionviewtoolview.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "versionviewtoolview.h"

// tool
#include "versionview.h"
#include "versionviewtool.h"

namespace Kasten {

VersionViewToolView::VersionViewToolView(VersionViewTool* tool)
    : mWidget(new VersionView(tool))
{
}

VersionViewToolView::~VersionViewToolView() = default;

QWidget* VersionViewToolView::widget()    const { return mWidget; }
QString VersionViewToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* VersionViewToolView::tool() const { return mWidget->tool(); }

}

==> okteta-0.26.0.tar.xz: okteta-0.26.0/libs/kasten/controllers/document/versionview/versionviewtoolview.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "versionviewtoolview.hpp"

// tool
#include "versionview.hpp"
#include "versionviewtool.hpp"

namespace Kasten {

VersionViewToolView::VersionViewToolView(VersionViewTool* tool)
    : mWidget(new VersionView(tool))
{
}

VersionViewToolView::~VersionViewToolView() = default;

QWidget* VersionViewToolView::widget()    const { return mWidget; }
QString VersionViewToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* VersionViewToolView::tool() const { return mWidget->tool(); }

}
